@@ -15,4 +15,4 @@ class Simulator:
 
     @property
     def samples(self):
-        return Predictive(self.model, {}, num_samples=self.num_samples)
+        return Predictive(self.model, {}, num_samples=self.num_samples)()
